@@ -1,8 +1,9 @@
-rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, xformula = formula(xdata), xdata = parent.frame(), 
-    link = "logit", cor.matrix = cor.matrix, rlatent = NULL) {
+rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, 
+    xformula = formula(xdata), xdata = parent.frame(), link = "logit", 
+    cor.matrix = cor.matrix, rlatent = NULL) {
     if (all.equal(clsize, as.integer(clsize)) != TRUE | clsize < 2) 
         stop("'clsize' must be a positive integer greater than or equal to two")
-    if (!is.vector(intercepts)) 
+    if (!(is.vector(intercepts) & !is.list(intercepts))) 
         stop("'intercepts' must be a vector")
     if (!is.numeric(intercepts)) 
         stop("'intercepts' must be numeric")
@@ -11,11 +12,11 @@ rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, xformu
     if (length(intercepts) != clsize) 
         stop("'intercepts' must have either one or ", clsize, " elements")
     intercepts <- cbind(-Inf, intercepts, Inf)
-    if (!is.vector(betas) & !is.matrix(betas)) 
+    if (!(is.vector(betas) & !is.list(betas)) & !is.matrix(betas)) 
         stop("'betas' must be a vector or a matrix")
     if (!is.numeric(betas)) 
         stop("'betas' must be numeric")
-    if (is.vector(betas)) {
+    if (is.vector(betas) & !is.list(betas)) {
         betas <- rep(betas, clsize)
     } else {
         if (nrow(betas) != clsize) 
@@ -24,15 +25,16 @@ rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, xformu
     }
     lpformula <- as.formula(xformula)
     if (length(paste0(attr(terms(lpformula), "variables"))) == 1) 
-      stop("No covariates were found in 'formula' ")
+        stop("No covariates were found in 'formula' ")
     Xmat <- model.matrix(lpformula, data = xdata)
     if (attr(terms(lpformula), "intercept") == 0) {
-      lpformula <- update(lpformula,~.+1)
+        lpformula <- update(lpformula, ~. + 1)
     }
-    Xmat <- matrix(Xmat[,-1],ncol=ncol(Xmat)-1)
+    Xmat <- matrix(Xmat[, -1], ncol = ncol(Xmat) - 1)
     if (length(betas) != (clsize) * ncol(Xmat)) 
         stop("The length of 'betas' does not match with the number of covariates")
-    lin.pred <- matrix(betas, nrow = nrow(Xmat), ncol = ncol(Xmat), byrow = TRUE) * Xmat
+    lin.pred <- matrix(betas, nrow = nrow(Xmat), ncol = ncol(Xmat),
+                       byrow = TRUE) * Xmat
     lin.pred <- matrix(rowSums(lin.pred), ncol = clsize, byrow = TRUE)
     lin.pred <- as.matrix(lin.pred)
     R <- nrow(lin.pred)
@@ -42,7 +44,9 @@ rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, xformu
         links <- c("probit", "logit", "cloglog", "cauchit")
         if (!is.element(link, links)) 
             stop("'link' must be 'probit','logit','cloglog' and/or 'cauchit'")
-        distr <- switch(link, probit = "qnorm", logit = "qlogis", cloglog = "qgumbel", cauchit = "qcauchy")
+        distr <- switch(link, probit = "qnorm", logit = "qlogis",
+                        cloglog = "qgumbel", 
+            cauchit = "qcauchy")
         if (!is.numeric(cor.matrix)) 
             stop("'cor.matrix' must be numeric")
         if (!is.matrix(cor.matrix)) 
@@ -55,7 +59,8 @@ rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, xformu
             stop("the diagonal elements of 'cor.matrix' must be one")
         if (any(cor.matrix > 1) | any(cor.matrix < -1)) 
             stop("all the elements of 'cor.matrix' must be on [-1,1]")
-        if (any(eigen(cor.matrix, symmetric = TRUE, only.values = TRUE)$values <= 0)) 
+        if (any(
+          eigen(cor.matrix, symmetric = TRUE, only.values = TRUE)$values <= 0)) 
             stop("'cor.matrix' must be positive definite")
         err <- rnorta(R, cor.matrix, rep(distr, clsize))
         if (distr == "qgumbel") 
@@ -72,11 +77,15 @@ rbin <- function(clsize = clsize, intercepts = intercepts, betas = betas, xformu
     }
     U <- lin.pred + err
     Ysim <- matrix(0, R, clsize)
-    for (i in 1:clsize) Ysim[, i] <- cut(U[, i] - 2 * lin.pred[, i], intercepts[i, ], labels = FALSE)
+    for (i in 1:clsize) Ysim[, i] <- 
+      cut(U[, i] - 2 * lin.pred[, i], intercepts[i, ], labels = FALSE)
     Ysim <- 2 - Ysim
     id <- rep(1:R, each = clsize)
     time <- rep(1:clsize, R)
     y <- c(t(Ysim))
-    simdata <- data.frame(y, model.frame(formula = lpformula, data = xdata), id, time)
+    rownames(Ysim) <- rownames(err) <- paste("i", 1:R, sep = "=")
+    colnames(Ysim) <- colnames(err) <- paste("t", 1:clsize, sep = "=")
+    simdata <- data.frame(y, model.frame(formula = lpformula, data = xdata), 
+        id, time)
     list(Ysim = Ysim, simdata = simdata, rlatent = err)
 }
