@@ -1,17 +1,20 @@
-rmult.bcl <- function(clsize = clsize, ncategories = ncategories, betas = betas, xformula = formula(xdata), xdata = parent.frame(), 
-    cor.matrix = cor.matrix, rlatent = NULL) {
+rmult.bcl <- function(clsize = clsize, ncategories = ncategories, 
+                      betas = betas, xformula = formula(xdata), 
+                      xdata = parent.frame(), cor.matrix = cor.matrix, 
+                      rlatent = NULL) {
     if (all.equal(clsize, as.integer(clsize)) != TRUE | clsize < 2) 
         stop("'clsize' must be a positive integer greater than or equal to two")
     if (!is.numeric(ncategories) | ncategories < 3) 
         stop("'ncategories' must be greater than or equal to three")
     ncategories <- as.integer(ncategories)
-    if (all.equal(ncategories, as.integer(ncategories)) != TRUE | ncategories < 3) 
+    if (all.equal(ncategories, as.integer(ncategories)) != TRUE | ncategories < 
+        3) 
         stop("'ncategories' must be a positive integer greater than or equal to three")
-    if (!is.vector(betas) & !is.matrix(betas)) 
+    if (!(is.vector(betas) & !is.list(betas)) & !is.matrix(betas)) 
         stop("'betas' must be a vector or a matrix")
     if (!is.numeric(betas)) 
         stop("'betas' must be numeric")
-    if (is.vector(betas)) {
+    if (is.vector(betas) & !is.list(betas)) {
         betas <- rep(betas, clsize)
     } else {
         if (nrow(betas) != clsize) 
@@ -22,17 +25,13 @@ rmult.bcl <- function(clsize = clsize, ncategories = ncategories, betas = betas,
     if (attr(terms(lpformula), "intercept") == 0) 
         stop("'formula' must have an intercept term")
     Xmat <- model.matrix(lpformula, data = xdata)
-#    att <- attr(Xmat, "assign")
-#    factor.columns <- unique(att[duplicated(att)])
-#    if (length(factor.columns) >= 1) {
-#      Xmat <- Xmat[, -match(factor.columns[1], att)]
-#      Xmat <- data.matrix(Xmat)
-#    }
     Xmat <- apply(Xmat, 2, function(x) rep(x, each = ncategories))
     if (length(betas) != (clsize * ncategories * ncol(Xmat))) 
         stop("The length of 'betas' does not match with the provided covariates")
-    lin.pred <- matrix(betas, nrow = nrow(Xmat), ncol = ncol(Xmat), byrow = TRUE) * Xmat
-    lin.pred <- matrix(rowSums(lin.pred), ncol = ncategories * clsize, byrow = TRUE)
+    lin.pred <- matrix(betas, nrow = nrow(Xmat), ncol = ncol(Xmat),
+                       byrow = TRUE) * Xmat
+    lin.pred <- matrix(rowSums(lin.pred), ncol = ncategories * clsize, 
+        byrow = TRUE)
     ncol.lp <- clsize * ncategories
     R <- nrow(lin.pred)
     if (is.null(rlatent)) {
@@ -50,7 +49,8 @@ rmult.bcl <- function(clsize = clsize, ncategories = ncategories, betas = betas,
         }
         if (any(cor.matrix > 1) | any(cor.matrix < -1)) 
             stop("all the elements of 'cor.matrix' must be on [-1,1]")
-        if (any(eigen(cor.matrix, symmetric = TRUE, only.values = TRUE)$values <= 0)) 
+        if (any(
+          eigen(cor.matrix, symmetric = TRUE, only.values = TRUE)$values <= 0)) 
             stop("'cor.matrix' must respect the local independence of the alternatives and must be positive definite")
         err <- rnorta(R, cor.matrix, rep("qgumbel", ncol.lp))
     } else {
@@ -64,13 +64,19 @@ rmult.bcl <- function(clsize = clsize, ncategories = ncategories, betas = betas,
         err <- rlatent
     }
     U <- lin.pred + err
-    U <- matrix(as.vector(t(U)), nrow = clsize * R, ncol = ncategories, TRUE)
+    U <- matrix(as.vector(t(U)), nrow = clsize * R, ncol = ncategories, 
+        TRUE)
     Ysim <- apply(U, 1, which.max)
     Ysim <- matrix(Ysim, ncol = clsize, byrow = TRUE)
     id <- rep(1:R, each = clsize)
     time <- rep(1:clsize, R)
     y <- c(t(Ysim))
     lpformula <- update(lpformula, ~. - 1)
-    simdata <- data.frame(y, model.frame(formula = lpformula, data = xdata), id, time)
+    rownames(Ysim) <- rownames(err) <- paste("i", 1:R, sep = "=")
+    colnames(Ysim) <- paste("t", 1:clsize, sep = "=")
+    colnames(err) <- paste("t=", rep(1:clsize, each = ncategories), " & j=", 
+        rep(1:ncategories, clsize), sep = "")
+    simdata <- data.frame(y, model.frame(formula = lpformula, data = xdata), 
+        id, time)
     list(Ysim = Ysim, simdata = simdata, rlatent = err)
 }
